This function computes the Generalized Directional Spillover Table which has as its
\(ij^{th}\) entry the estimated contribution to the forecast error variance
of variable i coming from innovations to variable j. The off-diagonal
column sums are the Contributions to Others, while the row sums represent
Contributions from Others, when these are totaled across countries then we have
the numerator of the Spillover Index. Similarly, the columns sums or rows sums
(including diagonal), when totaled across countries, give the denominator of the
Spillover Index, which is 100%.
G.spillover is based upon the General Forecast Error Variance Decompositon introduced by
Pesaran and Shin (1998) and its explicit formulation can be found in Diebold and Yilmaz (2010).