Learn R Programming

Spillover (version 0.1.1)

dynamic.spillover: dynamnic_spillover is a function for estimating DY directional spillovers.

Description

dynamnic_spillover is a function for estimating DY directional spillovers.

Usage

dynamic.spillover(
  data,
  width,
  n.ahead = 10,
  standardized = TRUE,
  na.fill = FALSE,
  remove.own = TRUE,
  ...
)

Value

A list of data.frames holding all directional spillovers as described in Diebold and Yilmaz (2012)

Arguments

data

a data.frame consisting of dates in its first column and numeric variables for the others

width

a integer specifying the window width in number of observations.

n.ahead

An integer indicating the how many steps ahead the spillover should be forecasted.

standardized

A logical value indicating whether the values should be divided by the number of columns to get a percentage.

na.fill

A logical value for filling with NA at the begining window due to width.

remove.own

should own directional spillover be removed?

...

Further arguments to be passed to var function

Examples

Run this code
data(dy2012)
# \donttest{
dy_results <- dynamic.spillover(data=dy2012, width=200, remove.own = FALSE) 
# } 

Run the code above in your browser using DataLab