powered by
dynamnic_spillover is a function for estimating DY directional spillovers.
dynamic.spillover( data, width, n.ahead = 10, standardized = TRUE, na.fill = FALSE, remove.own = TRUE, ... )
A list of data.frames holding all directional spillovers as described in Diebold and Yilmaz (2012)
a data.frame consisting of dates in its first column and numeric variables for the others
a integer specifying the window width in number of observations.
An integer indicating the how many steps ahead the spillover should be forecasted.
A logical value indicating whether the values should be divided by the number of columns to get a percentage.
A logical value for filling with NA at the begining window due to width.
width
should own directional spillover be removed?
Further arguments to be passed to var function
data(dy2012) # \donttest{ dy_results <- dynamic.spillover(data=dy2012, width=200, remove.own = FALSE) # }
Run the code above in your browser using DataLab